app_icons library
Classes
- AppDuotoneIconData
- AppFlatIconData
- AppIcon
- AppIconData
- AppIcons
- This class helps to access the icons of all the styles. Use the specific style class to access the icons of that style:
- AppIconsBold
- AppIconsDuotone
- AppIconsFill
- AppIconsLight
- AppIconsRegular
- AppIconsThin